"""
Transactional email response models for the Naxai SDK.

This module defines the data structures for responses from transactional email API operations,
providing models for tracking email creation and delivery status.
"""

from pydantic import BaseModel

class SendTransactionalEmailResponse(BaseModel):
    """
    Model representing the response from creating a new email in the Naxai email system.
    
    This class defines the structure for the API response when successfully submitting
    an email for delivery. It contains the unique identifier assigned to the email,
    which can be used for tracking and querying the email's status.
    
    Attributes:
        id (str): Unique identifier for the newly created email. This ID can be used
            to track the email's delivery status or retrieve details about the email.
    
    Example:
        >>> response = SendTransactionalEmailResponse(id="email_123abc456def")
        >>> print(f"Email created with ID: {response.id}")
        >>> print(f"You can track this email using the ID: {response.id}")
        Email created with ID: email_123abc456def
        You can track this email using the ID: email_123abc456def
        
    
    Note:
        - The email ID is generated by the system when the email is accepted for delivery
        - This ID should be stored if you need to track the email's status later
        - The email is not necessarily sent immediately; it's queued for delivery
        - Successful creation means the email was accepted for delivery, not that it was delivered
        - Additional details about the email (content, recipients, status) are not included
          in this response and must be retrieved separately using the email ID
    
    """
    id: str
